
<link href="../markdown.css" rel="stylesheet"></link>

<title>1.1. PDE Motivations and Context</title>

<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.0/MathJax.js?config=TeX-AMS_HTML">
    MathJax.Hub.Config({
        tex2jax: {
            inlineMath: [ ['$','$'], ["\\(","\\)"] ],
            displayMath: [ ['$$','$$'], ["\\[","\\]"] ],},
        TeX: {equationNumbers: {
            autoNumber: "AMS"
          },Augment: {  Definitions: {
           macros: {
             overbracket:  ['UnderOver','23B4',1],
             underbracket: ['UnderOver','23B5',1],
           }
         }}},
    });
</script>

$\renewcommand{\Re}{\operatorname{Re}}$
$\renewcommand{\Im}{\operatorname{Im}}$
$\newcommand{\erf}{\operatorname{erf}}$
$\newcommand{\dag}{\dagger}$
$\newcommand{\const}{\mathrm{const}}$



#[Chapter 1. Introduction](id:chapter-1)


##[1.1. PDE Motivations and Context](id:sect-1.1)
-----
> 1. [What is a PDE?](#sect-1.1.1)
> 2. [Where PDEs are coming from?](#sect-1.1.2)
> 3. [Examples of PDEs](#sect-1.1.3)



The aim of this is to introduce and motivate partial differential equations (PDE). The section also places the scope of studies in APM346 within the vast universe of mathematics.

###[What is a PDE?](id:sect-1.1.1)

A *partial differential equation (PDE)* is an *equation* involving *partial derivatives*. This is not so informative so let’s break it down a bit.

####[What is a differential equation?](id:sect-1.1.1.1)

An *ordinary differential equation (ODE)* is an equation for a function which depends on one independent variable which involves the independent variable, the function, and derivatives of the function:
\begin{equation\*}
F( t, u(t), u’(t), u^{(2)}(t), u^{(3)}(t), \\ldots, u^{(m)}(t)) = 0.
\end{equation\*}
This is an example of an ODE of *degree* $m$ where $m$ is a highest order of the derivative in the equation. Solving an equation like this on an interval $t\in [0,T]$ would mean finding a functoin $t \mapsto u(t) \in \mathbb{R}$ with the property that $u$ and its derivatives intertwine in such a way that this equation is true for all values of $t \in [0,T]$. The problem can be enlarged by replacing the real-valued $u$ by a vector-valued one $\mathbf{u}(t)= (u\_1 (t), u\_2 (t), \dots, u\_N (t))$. In this case we usually talk about *system of ODEs*.

Even in this situation, the challenge is to
find functions depending upon exactly one variable which, together with their derivatives, satisfy the equation.

####[What is a partial derivative?](id:sect-1.1.1.2)

When you have function that depends upon several variables, you can differentiate with respect to either variable while holding the other variable constant. This spawns the idea of *partial derivatives*. As an example, consider a function depending upon two real variables taking values in the reals:
\begin{equation\*}u:
\mathbb{R} ^n \to \mathbb{R}.
\end{equation\*}
As $n=2$ we sometimes visualize a function like this by considering its *graph* viewed as a surface in $\mathbb{R}^3$ given by the collection of points
\begin{equation\*}
\{ (x,y,z) \in {\\mathbb{R}^3}: z = u(x,y) \}.
\end{equation\*}
We can calculate the derivative with respect to $x$ while holding $y$ fixed. This leads to $u\_x$, also expressed as $\partial\_x u$,
$\frac{\partial u}{\partial x}$, and $\frac{\partial\ }{\partial x}$. Similary, we can hold $x$ fixed and differentiate with respect to $y$.

A *partial differential equation* is an equation for a function which depends on more than one independent variable which involves the independent variables, the function, and partial derivatives of the function:
\begin{equation\*}
F(x,y, u(x,y), u\_x (x,y), u\_y (x,y), u\_{xx} (x,y), u\_{xy}
(x,y), u\_{yx} (x,y), u\_{yy} (x,y)) = 0.
\end{equation\*}
This is an example of a PDE of degree 2. Solving an equation like this
would mean finding a function $(x,y) \to u(x,y)$ with the property that $u$ and is partial derivatives intertwine to satisfy the equation.

Similarly to ODE case this problem can be enlarged by replacing the real-valued $u$ by a vector-valued one $\mathbf{u}(t)= (u\_1 (t), u\_2 (t), \dots, u\_N (t))$. In this case we usually talk about *system of PDEs*.

###[Where PDEs are coming from?](id:sect-1.1.2)

PDEs are often referred as *Equations of Mathematical Physics* (or *Mathematical Physics* but it is incorrect as Mathematical Physics is now a separate field of mathematics) because many of PDEs are coming from different domains of physics (acoustics, optics, elasticity, hydro and aerodynamics, electromagnetism, quantum mechanics, seismology etc).

However PDEs appear in other field of science as well (like quantum chemistry, chemical kinetics); some PDEs are coming from economics and financial mathematics, or computer science.

Many PDEs are originated in other fields of mathematics.


###[Examples of PDEs](id:sect-1.1.3)
(Some are actually systems)

- Simplest First Order Equation \begin{equation\*} u\_x = 0; \end{equation\*}
- Transport Equation \begin{equation\*} u\_t + c u\_x = 0; \end{equation\*}
- Laplace’s Equation (in 2D) \begin{equation\*} \Delta u:=u\_{xx} + u\_{yy} = 0\end{equation\*} or similarly in the higher dimensions;
- Heat Equation \begin{equation\*} u\_t = k\Delta u;\end{equation\*}

(The expression $\Delta$ is called the *Laplacian* and is defined as $\partial\_{x}^2 + \partial\_{y}^2+\partial\_{z}^2$ on $\mathbb{R}^3$.)

- Schrödinger Equation (quantum mechanics)\begin{equation\*} i u\_t + \Delta u = 0;\end{equation\*}
- Wave Equation \begin{equation\*} u\_{tt} - c^2\Delta u = 0;\end{equation\*}
- Equation of oscillating rod (with one spatial variable) or plate (with two spatial variables)\begin{equation\*} u\_{tt} + K\Delta^2 u = 0;\end{equation\*}
- Maxwell Equation (electromagnetism)\begin{equation\*} \mathbf{E}\_{t} - c\nabla \times \mathbf{H} = 0,\quad \mathbf{H}\_{t} + c\nabla \times \mathbf{E} = 0,\quad \nabla\cdot\mathbf{E}=\nabla\cdot\mathbf{H}=0;\end{equation\*}
- Dirac Equations (quantum mechanics);
- Elasticity Equation\begin{equation\*}\mathbf{u}_{tt}=\lambda \Delta\mathbf{u}+\mu \nabla(\nabla\cdot\mathbf{u});\end{equation\*}
- Navier-Stokes Equation (hydrodynamics for incompressible liquid)\begin{equation\*} \rho\mathbf{v}\_{t} +  (\mathbf{v}\cdot \nabla ) \rho\mathbf{v} -\nu \Delta \mathbf{v}=-\nabla p,\quad \nabla \cdot \mathbf{v} = 0\end{equation\*} where $\mathbf{v}$ is a velocity and $p$ is the pressure; when viscosity $\nu=0$ we get Euler equation;
- Yang-Mills Equation (elementary particles theory);
- Einstein Equation for General Relativity;
and so on...

**[Remark 1.](id:remark-1.1.1)**

a. Some of these examples are actually not single PDEs but the systems of PDEs.
b. In all this examples there are *spatial variables* $x,y,z$ and often *time variable* $t$ but it is not necessarily so in all PDEs.
c. Equations could be of different order with respect to different variables and it is important. However if not specified the order of equation is the highest order of the derivatives invoked.
d. In the Textbook we will deal mainly with the wave equation, heat equation and Laplace equation in their simplest forms.
<!--\end{remark}-->


______
 [$\Leftarrow$](../Chapter0/S0.1.html)&nbsp;&nbsp;[$\Uparrow$](../contents.html)&nbsp;&nbsp;[$\Rightarrow$](./S1.2.html)
