
<link href="../markdown.css" rel="stylesheet"></link>

<title>1.2. Initial and Boundary Value Problems</title>

<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.0/MathJax.js?config=TeX-AMS_HTML">
    MathJax.Hub.Config({
        tex2jax: {
            inlineMath: [ ['$','$'], ["\\(","\\)"] ],
            displayMath: [ ['$$','$$'], ["\\[","\\]"] ],},
        TeX: {equationNumbers: {
            autoNumber: "AMS"
          },Augment: {  Definitions: {
           macros: {
             overbracket:  ['UnderOver','23B4',1],
             underbracket: ['UnderOver','23B5',1],
           }
         }}},
    });
</script>

$\renewcommand{\Re}{\operatorname{Re}}$
$\renewcommand{\Im}{\operatorname{Im}}$
$\newcommand{\erf}{\operatorname{erf}}$
$\newcommand{\dag}{\dagger}$
$\newcommand{\const}{\mathrm{const}}$





##[1.2. Initial and Boundary Value Problems](id:sect-1.2)
---


> 1. [Problems for PDEs](#sect-1.2.1)
> 2. [Notion of 'well-posedness'](#sect-1.2.2)





###[Problems for PDEs](id:sect-1.2.1)
We know that solutions of ODEs typically depend on one or several constants. For PDEs situation is more complicated. Consider simplest equations
\begin{gather}
u\_x =0,
\label{eq-1.2.1}\\\\
v\_{xy}=0
\label{eq-1.2.2}
\end{gather}
with $u=u(x,y)$ and $v=v(x,y)$. Equation (\ref{eq-1.2.1}) could be treaded as an ODE with respect to $x$ and its solution is a constant but this is not a genuine constant as *it is constant only with respect to $x$ and can depend on other variables*; so $u(x,y)=\phi(y)$.

Then for solution of (\ref{eq-1.2.2}) we have $v_y= \phi(y)$ where $\phi$ is an arbitrary function of one variable and it could be considered as ODE with respect to $y$; then $(v-g(y))_y=0$ where $g(y)=\int \phi(y)\,dy$, and therefore $v-g(y)=f(x)\implies v(x,y)=f(x)+g(y)$ where $f,g$ are arbitrary functions of one variable.

Considering these equations again but assuming that $u=u(x,y,z)$, $v=v(x,y,z)$ we arrive to $u=\phi(y,z)$ and $v=f(x,z)+g(y,z)$ where $f,g$ are arbitrary functions of two variables.

Solutions to PDEs typically depend not on several arbitrary constants but on one or several arbitrary functions of $n-1$ variables.  For more complicated equations this dependance could be much more complicated and implicit. To select a right solutions we need to use some extra conditions.


The sets of such conditions are called *Problems*. Typical problems are

- IVP (initial value problem): one of variables is interpreted as *time* $t$ and conditions are imposed at some moment; f.e. $u|_{t=t_0}=u_0$;
- BVP (boundary value problem) conditions are imposed on the boundary of the spatial domain $\Omega$: f.e. $u|_{\partial\Omega}=\phi$ where $\partial\Omega$ is a boundary of $Omega$;
- IVBP (initial-boundary value problems aka mixed problems): one of variables is interpreted as *time* $t$ and some conditions are imposed at some moment but other conditions are imposed on the boundary of the spatial domain.

**[Remark 1.](id:remark-1.2.1)**
In the course of ODEs students  usually consider IVP only. F.e. for the second-order equation like
\begin{equation\*}u\_{xx}+ a_1 u\_{x}+a\_2 u=f(x)\end{equation\*} such problem is $u|\_{x=x\_0}=u\_0$, $u\_x|\_{x=x_0}=u\_1$. However one could consider BVPs like
\begin{gather\*}(\alpha\_1 u_x+\beta\_1 u)|\_{x=x\_1}=\phi\_1,\\\\
(\alpha\_2 u\_x+\beta\_2 u)|\_{x=x\_2}=\phi\_2
\end{gather\*}
where solutions are sought on the interval $[x\_1,x\_2]$.
Such  are covered in advanced chapters of some of ODE textbooks (but not covered by a typical ODE class). We will need to cover such problems later in this Textbook.
<!--\end{remark}-->

###[Notion of "well-posedness"](id:sect-1.2.1)

We want that our PDE (or the system of PDEs) together with all these conditions satisfied the following requirements:

- Solutions must exist for all right-hand expressions (in equations and conditions);
- Solution must be unique;
- Solution must depend on this right-hand expressions continuously.

Such problems are called *well-posed*. PDEs are usually studied together with the problems which are well-posed for these PDEs. Different types of PDEs "admit" different problems.

Sometimes however one nedds to consider *ill-posed* problems.



________

[$\Leftarrow$](./S1.1.html)&nbsp;&nbsp;[$\Uparrow$](../contents.html)&nbsp;&nbsp;[$\Rightarrow$](./S1.3.html)
