<link href="../markdown.css" rel="stylesheet"></link>

<title>1.3. Classification of  equations</title>

<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.0/MathJax.js?config=TeX-AMS_HTML">
    MathJax.Hub.Config({
        tex2jax: {
            inlineMath: [ ['$','$'], ["\\(","\\)"] ],
            displayMath: [ ['$$','$$'], ["\\[","\\]"] ],},
        TeX: {equationNumbers: {
            autoNumber: "AMS"
          },Augment: {  Definitions: {
           macros: {
             overbracket:  ['UnderOver','23B4',1],
             underbracket: ['UnderOver','23B5',1],
           }
         }}},
    });
</script>

$\renewcommand{\Re}{\operatorname{Re}}$
$\renewcommand{\Im}{\operatorname{Im}}$
$\newcommand{\erf}{\operatorname{erf}}$
$\newcommand{\dag}{\dagger}$
$\newcommand{\const}{\mathrm{const}}$


##[1.3. Classification of  equations](id:sect-1.3)

> 1. [Linear and non-linear equations](#sect-1.3.1)
> 2. [Elliptic, hyperbolic and parabolic equations](#sect-1.3.2)
> 2. [Scope of this Textbook](#sect-1.3.3)


###[Linear and non-linear equations](id:sect-1.3.1)

Equations of the form
\begin{equation}
Lu = f(\mathbf{x})
\label{eq-1.3.1}
\end{equation}
where $Lu$ is a partial differential expression linear with respect to unknown function $u$ is called *linear equation* (or *linear system*). This equation is *linear homogeneous equation* if $f=0$ and *linear inhomogeneous equation* otherwise. For example,
\begin{equation}
Lu := a\_{11} u\_{xx} + 2a\_{12} u\_{xy}+a\_{22} u\_{yy}+ a\_1u\_x+a\_2 u\_y +a u = f(\mathbf{x})
\label{eq-1.3.2}
\end{equation}
is linear; if all coefficients $a\_{jk}$, $a\_j$, $a$ are constant, we call it *linear equation with constant coefficients*; otherwise we talk about *variable coefficients*.

Otherwise equation is called *non-linear*. However there is a more subtle classification  of such equations. Equations of the type (\ref{eq-1.3.1}) where the right-hand expression $f$ depend on the lower-order derivatives are called *semilinear*, equations where both coefficients and right-hand expression depend  on the lower-order derivatives are called *quasilinear*.
For example
\begin{equation}
Lu := a\_{11}(x,y) u\_{xx} + 2a\_{12}(x,y) u\_{xy}+a\_{22}(x,y) u\_{yy} = f(x,y,u,u\_x,u\_y)
\label{eq-1.3.3}
\end{equation}
is semilinear, and
\begin{multline}
Lu := a\_{11}(x,y,u,u\_x,u\_y) u\_{xx} +
2a\_{12}(x,y,u,u\_x,u\_y) u\_{xy}+a\_{22}(x,y,u,u\_x,u\_y) u\_{yy} \\\\= f(x,y,u,u\_x,u\_y)\qquad
\label{eq-1.3.4}
\end{multline}
is quasilinear, while
\begin{equation}
F(x,y,u,u\_x,u\_y,u\_{xx},u\_{xy},u\_{yx}) =0
\label{eq-1.3.5}
\end{equation}
is general *nonlinear*.

###[Elliptic, hyperbolic and parabolic equations](id:sect-1.3.2)
####[General](id:sect-1.3.2.1)
Consider second order equation (\ref{eq-1.3.2}):
\begin{equation}
Lu := \sum\_{1\le i,j\le n} a\_{ij} u\_{x\_ix\_j} + \text{l.o.t.} = f(\mathbf{x})
\label{eq-1.3.6}
\end{equation}
where l.o.t. means *lower order terms* with $a\_{ij}=a\_{ji}$. Let us change variables $\mathbf{x}=\mathbf{x}(\mathbf{x}')$. Then the *matrix of principal coefficients*   $A=\begin{pmatrix} a\_{11} &  \dots &a\_{1n}\\\\ \vdots  & \ddots &\vdots \\\\ a\_{n1}&\dots & a\_{nn}\end{pmatrix}$ in the new coordinate system becomes  $A'=  Q^\* A Q$ where $Q=T^{\*\,-1}$ and $T=\left( \frac{\partial x\_i}{\partial x'\_j}\right)\_{i,j=1,\dots,n}$ is a Jacobi matrix. The proof easily follows from the *chain rule* (Calculus II).

Therefore if the principal coefficients are real and constant, by a linear change of variables matrix of the principal coefficients could be reduced to the diagonal form, where diagonal elements could be either $1$, or $-1$ or $0$. Multiplying equation by $-1$ if needed we can assume that there are at least as many $1$ as $-1$. In particular as $n=2$ the principal part becomes either
$u\_{xx}+u\_{yy}$, or $u\_{xx}-u\_{yy}$, or $u\_{xx}$ and such equations are called *elliptic*, *hyperbolic*, and *parabolic* respectively (there will be always second derivative as otherwise it would be the first order equation).

> This terminology comes from the curves of the second order 9aka *conical sections*: if $a\_{11}a\_{22}-a\_{12}^2>0$ equation $a\_{11}\xi ^2+2a\_{12}\xi\eta + a\_{22}\eta ^2+a\_1\xi +a_2\eta =c$ generically defines an ellipse, if $a\_{11}a\_{22}-a\_{12}^2<0$ this equation generically defines a hyperbole and if $a\_{11}a\_{22}-a\_{12}^2=0$ it defines a parabole.

Let us consider equations in different dimensions:

###[2D](id:sect-1.3.2.2)
If we consider only $2$-nd order equations with constant real
coefficients then in appropriate coordinates they will look like either
\begin{equation}
u\_{xx}+u\_{yy}+\text{l.o.t} =f
\label{eq-1.3.7}
\end{equation}
or
\begin{equation}
u\_{xx}-u\_{yy}+\text{l.o.t.} =f.
\label{eq-1.3.8}
\end{equation}
and we call such equations  *elliptic* and  *hyperbolic* respectively.

What to do if one of the 2-nd derivatives is missing? We get *parabolic equations*
\begin{equation}
u\_{xx}-cu\_{y}+\text{l.o.t.} =f.
\label{eq-1.3.9}
\end{equation}
with $c\ne 0$ (we do not consider $cu\_y$ as a lower order term here) and IVP $u|\_{y=0}=g$ is well-posed in the direction of $y\>0$ if $c\>0$ and in direction $y\<0$ if $c\<0$. We can dismiss $c=0$ as not-interesting.

However this classification leaves out very important Schrödinger equation \begin{equation}
u\_{xx} +i c u\_y=0
\label{eq-1.3.10}
\end{equation}
with real $c\ne 0$. For it IVP $u|\_{y=0}=g$ is well-posed in both directions $y\>0$ and $y\<0$ but it lacks many properties of parabolic equations (like maximum principle or mollification; still it has interesting properties on its own).

####[3D](id:sect-1.3.2.3)
Again, if we consider only $2$-nd order equations with constant real coefficients then in appropriate coordinates they will look like either
\begin{equation}
u\_{xx}+u\_{yy}+u\_{zz}+\text{l.o.t} =f
\label{eq-1.3.11}
\end{equation}
or
\begin{equation}
u\_{xx}+u\_{yy}-u\_{zz}+\text{l.o.t.} =f.
\label{eq-1.3.12}
\end{equation}
and we call such equations  *elliptic* and  *hyperbolic* respectively.

Also we get *parabolic equations* like
\begin{equation}
u\_{xx}+u\_{yy}-cu\_z+\text{l.o.t.} =f.
\label{eq-1.3.13}
\end{equation}
What about
\begin{equation}
u\_{xx}-u\_{yy}-cu\_z+\text{l.o.t.} =f?
\label{eq-1.3.14}
\end{equation}
Algebraist-formalist would call it parabolic-hyperbolic but since this equation exhibits no interesting analytic properties (unless one considers lack of such properties interesting; in particular, IVP is ill-posed in both directions) it would be a perversion.

Yes, there will be Schrödinger equation
\begin{equation}
u\_{xx} +u\_{yy}+i c u\_z=0
\label{eq-1.3.15}
\end{equation}
with real $c\ne 0$ but $u\_{xx} -u\_{yy}+i c u\_z=0$ would also have IVP
$u|\_{z=0}=g$ well-posed in both directions.

####[4D](id:sect-1.3.2.4)
Here we would get also *elliptic*
\begin{equation}
u\_{xx}+u\_{yy}+u\_{zz}+u\_{tt}+\text{l.o.t.} =f,
\label{eq-1.3.16}
\end{equation}
*hyperbolic*
\begin{equation}
u\_{xx}+u\_{yy}+u\_{zz}-u\_{tt}+\text{l.o.t.} =f,
\label{eq-1.3.17}
\end{equation}
but also *ultrahyperbolic*
\begin{equation}
u\_{xx}+u\_{yy}-u\_{zz}-u\_{tt}+\text{l.o.t.} =f
\label{eq-1.3.18}
\end{equation}
which exhibits some interesting analytic properties but these equations are way less important than elliptic, hyperbolic or parabolic.

Parabolic and Schrödinger will be here as well.

**[Remark 1.](id:remark-1.3.1)**
The notions of elliptic, hyperbolic or parabolic equations are generalized to higher dimensions (trivially) and to higher-order equations but most of the randomly written equations do not belong to any of these types and there is no reason to classify them.

There is no complete classifications of PDEs and cannot be because any reasonable classification should not be based on how equation looks like but on the reasonable analytic properties it exhibits (which IVP or BVP are well-posed etc).
<!--\end{remark}-->

####[Equations of the variable type](id:sect-1.3.2.5)
To make things even more complicated there are equations changing types from point to point, f.e. Tricomi equation
\begin{equation}
u\_{xx}+xu\_{yy}=0
\label{eq-1.3.19}
\end{equation}
which is elliptic as $x\>0$ and hyperbolic as $x\<0$ and at $x=0$ has a "parabolic degeneration". It is a toy-model describing stationary transsonic flow of gas. These equations are called *equations of the variable type* (aka *mixed equations*).

Our purpose was not to give exact definitions but to explain a situation.


###[Scope of this Textbook](id:sect-1.3.3)
- We mostly consider *linear* PDE problems.
- We mostly consider *well-posed problems*
- We mostly consider problems with *constant coefficients*.
- We do not consider *numerical methods.*

________

[$\Leftarrow$](./S1.2.html)&nbsp;&nbsp;[$\Uparrow$](../contents.html)&nbsp;&nbsp;[$\Rightarrow$](./S1.4.html)


